@@ -3,24 +3,25 @@
 """Tests for `py_casim` package."""
 
 import re
+
 import pytest
 
 from py_casim.casim import Casim
 
 
 @pytest.fixture(scope='function')
-def casim_inst(datadir):
+def casim_inst(shared_datadir):
     """Instantiate a casim objetc with sample image.
 
     See more at: http://doc.pytest.org/en/latest/fixture.html
     """
-    image = (datadir / 'sample image.png')
+    image = (shared_datadir / 'sample image.png')
     return Casim(image, resize=125)
 
 
 def test_repr(casim_inst):
     """Test __repr__."""
-    assert re.match(r"Casim\((.*(/|\\)test_casim(/|\\)sample image\.png), resize=125\)",  # noqa: E501
+    assert re.match(r"Casim\((.*(/|\\)data(/|\\)sample image\.png), resize=125\)",  # noqa: E501
                     repr(casim_inst))
 
 
